@@ -138,6 +138,10 @@ class LogicBlock:
     name: str
     content: list['Check | LogicBlock'] = field(default_factory=list)
 
+    @property
+    def child_blocks(self) -> list['LogicBlock']:
+        return [c for c in self.content if isinstance(c, LogicBlock)]
+
     def add(self, block: 'Check | LogicBlock') -> None:
         self.content.append(block)
 
@@ -187,9 +191,9 @@ def parse_tokens_as_logic(tokens: list[dict], root_name: str) -> LogicBlock:
             target_parent = root
             target_depth = token.get('attrs', {}).get('level', 0)
             for _ in range(target_depth - 1):
-                if not target_parent.content:
+                if not target_parent.child_blocks:
                     target_parent.add(LogicBlock(block_name))
-                target_parent = target_parent.content[-1]
+                target_parent = target_parent.child_blocks[-1]
             target_parent.add(current_block := LogicBlock(block_name))
 
     return root
